#include "mainwidget.h"
#include "ui_mainwidget.h"
#include <QDebug>
#include <QSqlError>
#include <QSortFilterProxyModel>

MainWidget::MainWidget(QWidget *parent) :
  QWidget(parent),
  ui(new Ui::MainWidget)
{
  ui->setupUi(this);

  //Настройки для подключения к СУБД Interbase/Firebird
  db = QSqlDatabase::addDatabase("QIBASE");
  db.setDatabaseName("d:\\Tutorials\\TUTORIALDB.FDB"); //Ваш путь к файлу БД
  db.setUserName("SYSDBA");    //или какой-то другой пользователь БД
  db.setPassword("masterkey"); //или пароль пользователя, указанного через setUserName()

  //Проверка соединения с БД
  if (!db.open()){
    qDebug() << db.lastError().text();
    return;
  }
  else {
    qDebug() << "Success!";
  }

  //!!!! Можно использовать любую модель (наследуемую от класса QAbstractItemModel)
  //!!!! Для простоты можно использовать QStandardItemModel
  model = new QSqlTableModel(this, db);
  //Указываем стратегию кэширования изменений
  model->setEditStrategy(QSqlTableModel::OnManualSubmit);
  //Указываем имя таблицы, данные которой хотим загрузить в модель
  model->setTable("products");
  //Загрузка актуальных данных таблицы из БД
  model->select();

  ui->tableView->setModel(model);

  //Создание единственного экземпляра формы редактирования строки
  editForm = new RecordEditForm();
  //Назначение родительского виджета и указание виджету типа "Окно"
  editForm->setParent(this, Qt::Window);
  //Назначение модели для формы редактирования
  editForm->setModel(model);
}

MainWidget::~MainWidget()
{
  delete ui;
}

void MainWidget::on_btnSubmit_clicked()
{
  //Применение всех закэшированных изменений к БД
  model->submitAll();
}

void MainWidget::on_btnRevert_clicked()
{
  //Откат всех закэшированных (то есть не сохраненных в БД) изменений
  model->revertAll();
}

void MainWidget::on_tableView_doubleClicked(const QModelIndex &index)
{
  //Указываем объекту связи (mapper) индекс редактирумой строки
  editForm->mapper->setCurrentModelIndex(index);
  //Показываем окно редактирование
  editForm->show();
}
